@@ -61,8 +61,8 @@ void ArticleList::fillTable(QList<QString> searchTitles, QString keyword)
         int i = 0;
         foreach (QString title, searchTitles)
         {
-            QTableWidgetItem *newItem = new QTableWidgetItem(QIcon(":/images/play.png"), title);
-            QTableWidgetItem *newItem2 = new QTableWidgetItem(QIcon(":/images/add.png"), "");
+            QTableWidgetItem *newItem = new QTableWidgetItem(QIcon(":/images/Icon_player_small.png"), title);
+            QTableWidgetItem *newItem2 = new QTableWidgetItem(QIcon(":/images/Icon_plus.png"), "");
             this->ui->tableWidget->setItem(i,0, newItem);
             this->ui->tableWidget->setItem(i,1, newItem2);
             this->ui->tableWidget->setRowHeight(i, 80);
