@@ -36,7 +36,6 @@ MainWindow::MainWindow(QWidget *parent)
     connect(articleList, SIGNAL(articleToPlaylist(QString,QString)), this, SLOT(addToPlaylist(QString,QString)));
     connect(network, SIGNAL(playlistArticleSaved()), message, SLOT(hide()));
     connect(player, SIGNAL(openArticleFromLink(QListWidgetItem*)), this, SLOT(openArticleFromLink(QListWidgetItem*)));
-    connect(options, SIGNAL(removePlaylistsButtonClicked()), this, SLOT(removePlaylistsMode()));
     connect(player, SIGNAL(audioCreated()), message, SLOT(hide()));
    // connect(network, SIGNAL(downloadProgress(qint64,qint64)), this, SLOT(updateProgressBar(qint64,qint64)));
 }
@@ -303,9 +302,3 @@ void MainWindow::on_searchLineEdit_returnPressed()
         this->searchWord = this->ui->searchLineEdit->text();
     }
 }
-
-void MainWindow::removePlaylistsMode()
-{
-
-
-}
